package cn.com.infosec.asn1.isismtt.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class CertHash extends ASN1Encodable {
   private AlgorithmIdentifier hashAlgorithm;
   private byte[] certificateHash;

   public static CertHash getInstance(Object obj) {
      if (obj != null && !(obj instanceof CertHash)) {
         if (obj instanceof ASN1Sequence) {
            return new CertHash((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (CertHash)obj;
      }
   }

   private CertHash(ASN1Sequence seq) {
      if (seq.size() == 2) {
         this.hashAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(0));
         this.certificateHash = ASN1OctetString.getInstance(seq.getObjectAt(1)).getOctets();
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public CertHash(AlgorithmIdentifier hashAlgorithm, byte[] certificateHash) {
      this.hashAlgorithm = hashAlgorithm;
      byte[] var3;
      this.certificateHash = var3 = new byte[certificateHash.length];
      int hashAlgorithm1 = certificateHash.length;
      System.arraycopy(certificateHash, 0, var3, 0, hashAlgorithm1);
   }

   public AlgorithmIdentifier getHashAlgorithm() {
      return this.hashAlgorithm;
   }

   public byte[] getCertificateHash() {
      return this.certificateHash;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10000.add(this.hashAlgorithm);
      var10000.add(new DEROctetString(this.certificateHash));
      return new DERSequence(var1);
   }
}
